namespace elm { 
inline ::efl::eolian::return_traits<void>::type Notify::align_get( ::efl::eolian::out_traits<double>::type horizontal,  ::efl::eolian::out_traits<double>::type vertical) const
{
   double __out_param_horizontal = {};
   double __out_param_vertical = {};
    ::elm_obj_notify_align_get(this->_eo_ptr()
      , & __out_param_horizontal
      , & __out_param_vertical);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(horizontal, __out_param_horizontal);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(vertical, __out_param_vertical);
}
inline ::efl::eolian::return_traits<void>::type Notify::align_set( ::efl::eolian::in_traits<double>::type horizontal,  ::efl::eolian::in_traits<double>::type vertical) const
{
    ::elm_obj_notify_align_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(horizontal)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(vertical));
}
inline ::efl::eolian::return_traits<bool>::type Notify::allow_events_get() const
{
   Eina_Bool __return_value =  ::elm_obj_notify_allow_events_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Notify::allow_events_set( ::efl::eolian::in_traits<bool>::type allow) const
{
    ::elm_obj_notify_allow_events_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(allow));
}
inline ::efl::eolian::return_traits<double>::type Notify::timeout_get() const
{
   double __return_value =  ::elm_obj_notify_timeout_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Notify::timeout_set( ::efl::eolian::in_traits<double>::type timeout) const
{
    ::elm_obj_notify_timeout_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(timeout));
}
inline ::efl::eolian::return_traits<void>::type Notify::dismiss() const
{
    ::elm_obj_notify_dismiss(this->_eo_ptr());
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<void>::type Notify::align_get( ::efl::eolian::out_traits<double>::type horizontal,  ::efl::eolian::out_traits<double>::type vertical) const
{
   double __out_param_horizontal = {};
   double __out_param_vertical = {};
    ::elm_obj_notify_align_get(this->_eo_ptr()
      , & __out_param_horizontal
      , & __out_param_vertical);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(horizontal, __out_param_horizontal);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(vertical, __out_param_vertical);
}
inline ::efl::eolian::return_traits<void>::type Notify::align_set( ::efl::eolian::in_traits<double>::type horizontal,  ::efl::eolian::in_traits<double>::type vertical) const
{
    ::elm_obj_notify_align_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(horizontal)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(vertical));
}
inline ::efl::eolian::return_traits<bool>::type Notify::allow_events_get() const
{
   Eina_Bool __return_value =  ::elm_obj_notify_allow_events_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Notify::allow_events_set( ::efl::eolian::in_traits<bool>::type allow) const
{
    ::elm_obj_notify_allow_events_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(allow));
}
inline ::efl::eolian::return_traits<double>::type Notify::timeout_get() const
{
   double __return_value =  ::elm_obj_notify_timeout_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Notify::timeout_set( ::efl::eolian::in_traits<double>::type timeout) const
{
    ::elm_obj_notify_timeout_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(timeout));
}
inline ::efl::eolian::return_traits<void>::type Notify::dismiss() const
{
    ::elm_obj_notify_dismiss(this->_eo_ptr());
}
inline elm::Notify::operator ::elm::Notify() const { return *static_cast< ::elm::Notify const*>(static_cast<void const*>(this)); }
inline elm::Notify::operator ::elm::Notify&() { return *static_cast< ::elm::Notify*>(static_cast<void*>(this)); }
inline elm::Notify::operator ::elm::Notify const&() const { return *static_cast< ::elm::Notify const*>(static_cast<void const*>(this)); }
} }

